#include <obgnome/obgnome.h>
#include <gemvt/gtkled.h>


@interface GULPMainWin : Gnome_AppWin
{
@public
   id app;
}
- menu_help_about:(id) anobj;
- menu_file_exit:(id) anobj;
@end

@interface GULPApp : Gnome_App
{
	PrintSystem *printsys;
	GULPMainWin *mainwin;
	Gtk_VBox *vbox;
	Gtk_ScrolledWindow *listscroller;
	Gtk_List *printerlist;
	Gtk_ListItem **printers;
	/* We should really write a wrapper for GtkLed */
	Gtk_Misc **leds;
	Gtk_Label **lbls;
	
	struct {
		struct {
			Gtk_VBox *page;
			Gtk_CList *joblist;
			Gtk_ListItem **jobs;
			Gtk_Button *canceljob;
		} jobs;
		struct {
			Gtk_HBox *page;
			Gtk_CheckButton *updown, *startstop;
			Gtk_Button *clean, *restart;
		} printops;
	} nb;
	int dotogglehandler;
}
- clicked:(id) obj;
- selection_changed:(id) obj;
- dojoblist;
@end

@interface Gtk_MessageBox : Gtk_Dialog
{
	Gtk_Button *btn_ok;
	Gtk_Label *lbl_msg;
}
- initWithLabel:(gchar *) label;
- run;
- clicked:(id) obj;
- destroy:(id) obj;
@end
